@@ -40,7 +40,7 @@ MainWindow::MainWindow(const QStringList& args) :
     setWindowFlags(Qt::Window); // for the close, min and max buttons
     setup();
     ui->combo_Usb->addItems(buildUsbList());
-    if (args.size() > 1) {
+    if (args.size() > 1 && args.at(1) != "%f") {
         ui->buttonSelectSource->setText(args.at(1));
         ui->buttonSelectSource->setToolTip(args.at(1));
         ui->buttonSelectSource->setIcon(QIcon::fromTheme("media-cdrom"));
@@ -229,7 +229,7 @@ void MainWindow::cleanup()
 // build the USB list
 QStringList MainWindow::buildUsbList()
 {
-    QString drives = cmd.getCmdOut("lsblk --nodeps -nlo name,size,model,vendor -I 3,8,22,179,259");
+    QString drives = cmd.getCmdOut("lsblk --nodeps -nlo NAME,SIZE,MODEL,VENDOR -I 3,8,22,179,259");
     return removeUnsuitable(drives.split("\n"));
 }
 
