@@ -7,233 +7,277 @@
         <translation>Program_Name</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="33"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Wybierz docelowe urządzenie USB&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="43"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Wybierz plik ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="88"/>
-        <location filename="mainwindow.cpp" line="446"/>
-        <location filename="mainwindow.cpp" line="464"/>
-        <source>Select ISO</source>
-        <translation>Wybierz ISO</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="100"/>
-        <source>Refresh drive list</source>
-        <translation>Odśwież listę napędów</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="112"/>
-        <location filename="mainwindow.cpp" line="393"/>
-        <location filename="mainwindow.cpp" line="399"/>
-        <source>Show advanced options</source>
-        <translation>Pokaż opcje zaawansowane</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="130"/>
-        <source>Advanced Options</source>
-        <translation>Zaawansowane opcje</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="139"/>
-        <source>Verbosity (less to more):</source>
-        <translation>Szczegółowość (mniej oznacza większą):</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="190"/>
-        <source>Size of ESP (uefi) partition:</source>
-        <translation>Rozmiar partycji ESP (uefi):</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="222"/>
-        <source>Make the ext4 filesystem even if one exists</source>
-        <translation>Utwórz system plików ext4, nawet jeśli taki istnieje</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="229"/>
-        <source>Save the original boot directory when updating a live-usb</source>
-        <translation>Zapisz oryginalny katalog rozruchowy podczas aktualizacji live-usb</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="236"/>
-        <source>Use gpt partitioning instead of msdos</source>
-        <translation>Użyj partycjonowania gpt zamiast msdos</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="239"/>
-        <source>GPT partitioning</source>
-        <translation>Partycjonowanie GPT</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="246"/>
-        <source>Update (only update an existing live-usb)</source>
-        <translation>Aktualizuj (aktualizuj tylko istniejący live-usb)</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="253"/>
-        <source>Don&apos;t replace syslinux files</source>
-        <translation>Nie zastępuj plików syslinux</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="256"/>
-        <source>Keep syslinux files</source>
-        <translation>Zachowaj pliki syslinux</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="263"/>
-        <source>Ignore USB/removable check</source>
-        <translation>Zignoruj sprawdzanie USB/pamięci przenośnej</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="270"/>
-        <source>Temporarily disable automounting</source>
-        <translation>Tymczasowo wyłącz automontowanie</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="280"/>
-        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
-        <translation>Ustaw flagę dysku pmbr_boot (nie uruchomi się przez UEFI)</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="293"/>
-        <source>Options</source>
-        <translation>Opcje</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="308"/>
-        <source>Don&apos;t run commands that affect the usb device</source>
-        <translation>Nie uruchamiaj poleceń, które wpływają na urządzenie USB</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="311"/>
-        <source>Dry run (no change to system)</source>
-        <translation>Przebieg próbny (bez zmian w systemie)</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="318"/>
-        <source>clone from a mounted live-usb or iso-file.</source>
-        <translation>klonuj z zamontowanego live-usb lub pliku iso.</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="321"/>
-        <source>Clone an existing live system</source>
-        <translation>Klonuj istniejący system live</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="328"/>
-        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
-        <translation>Ustawienie rozruchu z zaszyfrowanej partycji spowoduje wyświetlenie prośby o podanie hasła przy pierwszym uruchomieniu</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="331"/>
-        <source>Encrypt</source>
-        <translation>Szyfruj</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="338"/>
-        <source>Clone running live system</source>
-        <translation>Klonuj uruchomiony system live</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="345"/>
-        <source>Read-only, cannot be used with persistency</source>
-        <translation>Tylko do odczytu, nie można zapisywać danych korzystając z Persistence</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="348"/>
-        <source>Copy image to USB (dd)</source>
-        <translation>Skopiuj obraz do USB (dd)</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="371"/>
-        <source>Percent of USB-device to use:</source>
-        <translation>Procent urządzenia USB do wykorzystania:</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="394"/>
-        <source>Label ext partition:</source>
-        <translation>Etykieta partycji ext:</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="442"/>
-        <source>For distros other than antiX/MX use &quot;Copy image to USB (dd)&quot; only.</source>
-        <translation>Dla dystrybucji innych niż antiX/MX użyj opcji &quot;Skopiuj obraz do USB (dd)&quot;</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="499"/>
+        <location filename="mainwindow.ui" line="46"/>
         <source>Quit application</source>
         <translation>Zakończ aplikację</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="502"/>
+        <location filename="mainwindow.ui" line="49"/>
         <source>Close</source>
         <translation>Zamknij</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="510"/>
+        <location filename="mainwindow.ui" line="56"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="542"/>
+        <location filename="mainwindow.ui" line="88"/>
         <source>Display help </source>
         <translation>Wyświetl pomoc</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="545"/>
+        <location filename="mainwindow.ui" line="91"/>
         <source>Help</source>
         <translation>Pomoc</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="553"/>
+        <location filename="mainwindow.ui" line="98"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="569"/>
+        <location filename="mainwindow.ui" line="114"/>
         <source>Back</source>
         <translation>Wstecz</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="628"/>
+        <location filename="mainwindow.ui" line="172"/>
         <source>Next</source>
         <translation>Dalej</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="655"/>
+        <location filename="mainwindow.ui" line="198"/>
         <source>About this application</source>
         <translation>O programie</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="658"/>
+        <location filename="mainwindow.ui" line="201"/>
         <source>About...</source>
         <translation>O...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="666"/>
+        <location filename="mainwindow.ui" line="208"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="72"/>
-        <location filename="mainwindow.cpp" line="239"/>
-        <location filename="mainwindow.cpp" line="379"/>
+        <location filename="mainwindow.ui" line="239"/>
+        <location filename="mainwindow.cpp" line="462"/>
+        <location filename="mainwindow.cpp" line="481"/>
+        <source>Select ISO</source>
+        <translation>Wybierz ISO</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="250"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Wybierz docelowe urządzenie USB&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="260"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Wybierz plik ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="289"/>
+        <source>Advanced Options</source>
+        <translation>Zaawansowane opcje</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="307"/>
+        <source>Make the ext4 filesystem even if one exists</source>
+        <translation>Utwórz system plików ext4, nawet jeśli taki istnieje</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="314"/>
+        <source>Save the original boot directory when updating a live-usb</source>
+        <translation>Zapisz oryginalny katalog rozruchowy podczas aktualizacji live-usb</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="321"/>
+        <source>Use gpt partitioning instead of msdos</source>
+        <translation>Użyj partycjonowania gpt zamiast msdos</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="324"/>
+        <source>GPT partitioning</source>
+        <translation>Partycjonowanie GPT</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="331"/>
+        <source>Update (only update an existing live-usb)</source>
+        <translation>Aktualizuj (aktualizuj tylko istniejący live-usb)</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="338"/>
+        <source>Don&apos;t replace syslinux files</source>
+        <translation>Nie zastępuj plików syslinux</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="341"/>
+        <source>Keep syslinux files</source>
+        <translation>Zachowaj pliki syslinux</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="348"/>
+        <source>Ignore USB/removable check</source>
+        <translation>Zignoruj sprawdzanie USB/pamięci przenośnej</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="355"/>
+        <source>Temporarily disable automounting</source>
+        <translation>Tymczasowo wyłącz automontowanie</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="365"/>
+        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
+        <translation>Ustaw flagę dysku pmbr_boot (nie uruchomi się przez UEFI)</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="372"/>
+        <source>Don&apos;t use fuseiso to mount iso files</source>
+        <translation>Nie używaj fuseiso do montowania plików iso</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="398"/>
+        <source>Size of ESP (uefi) partition:</source>
+        <translation>Rozmiar partycji ESP (uefi):</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="418"/>
+        <source>Verbosity (less to more):</source>
+        <translation>Szczegółowość (mniej oznacza większą):</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="457"/>
+        <source>vfat</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="462"/>
+        <source>exfat</source>
+        <translation>exFAT</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="467"/>
+        <source>ext4</source>
+        <translation>EXT4</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="472"/>
+        <source>ntfs</source>
+        <translation>NTFS</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="493"/>
+        <source>Make separate data partition (percent)</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="500"/>
+        <source>Format</source>
+        <translation>Formatuj</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="510"/>
+        <source>Refresh drive list</source>
+        <translation>Odśwież listę napędów</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="524"/>
+        <location filename="mainwindow.cpp" line="407"/>
+        <source>Show advanced options</source>
+        <translation>Pokaż opcje zaawansowane</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="544"/>
+        <source>Mode</source>
+        <translation>Tryb</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="559"/>
+        <source>Full-featured mode - writable LiveUSB</source>
+        <translation>W pełni funkcjonalny - zapisywalny LiveUSB</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="569"/>
+        <source>Read-only, cannot be used with persistency</source>
+        <translation>Tylko do odczytu, nie można zapisywać danych korzystając z Persistence</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="572"/>
+        <source>Image mode - read-only LiveUSB (dd)</source>
+        <translation>Tryb obrazu - LiveUSB tylko do odczytu (dd)</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="586"/>
+        <source>For distros other than antiX/MX use image mode (dd).</source>
+        <translation>Dla dystrybucji innych niż antiX/MX, użyj trybu obrazu (dd).</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="634"/>
+        <source>Options</source>
+        <translation>Opcje</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="669"/>
+        <source>Percent of USB-device to use:</source>
+        <translation>Procent urządzenia USB do wykorzystania:</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="676"/>
+        <source>Label ext partition:</source>
+        <translation>Etykieta partycji ext:</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="724"/>
+        <source>Don&apos;t run commands that affect the usb device</source>
+        <translation>Nie uruchamiaj poleceń, które wpływają na urządzenie USB</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="727"/>
+        <source>Dry run (no change to system)</source>
+        <translation>Przebieg próbny (bez zmian w systemie)</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="734"/>
+        <source>clone from a mounted live-usb or iso-file.</source>
+        <translation>klonuj z zamontowanego live-usb lub pliku iso.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="737"/>
+        <source>Clone an existing live system</source>
+        <translation>Klonuj istniejący system live</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="744"/>
+        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
+        <translation>Ustawienie rozruchu z zaszyfrowanej partycji spowoduje wyświetlenie prośby o podanie hasła przy pierwszym uruchomieniu</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="747"/>
+        <source>Encrypt</source>
+        <translation>Szyfruj</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="754"/>
+        <source>Clone running live system</source>
+        <translation>Klonuj uruchomiony system live</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="86"/>
+        <location filename="mainwindow.cpp" line="267"/>
+        <location filename="mainwindow.cpp" line="392"/>
         <source>Failure</source>
         <translation>Niepowodzenie</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="72"/>
+        <location filename="mainwindow.cpp" line="86"/>
         <source>Source and destination are on the same device, please select again.</source>
         <translation>Źródło i miejsce docelowe znajdują się na tym samym urządzeniu, proszę wybierz ponownie.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="94"/>
+        <location filename="mainwindow.cpp" line="111"/>
         <source>Writing %1 using 'dd' command to /dev/%2,
 
 Please wait until the the process is completed</source>
@@ -242,97 +286,96 @@ Please wait until the the process is completed</source>
 Poczekaj, aż proces się zakończy.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="237"/>
+        <location filename="mainwindow.cpp" line="265"/>
         <source>Success</source>
         <translation>Sukces </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="237"/>
+        <location filename="mainwindow.cpp" line="265"/>
         <source>LiveUSB creation successful!</source>
         <translation>Tworzenie LiveUSB zakończyło się sukcesem!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="239"/>
+        <location filename="mainwindow.cpp" line="267"/>
         <source>Error encountered in the LiveUSB creation process</source>
         <translation>Wystąpił błąd podczas tworzenia LiveUSB.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="285"/>
+        <location filename="mainwindow.cpp" line="316"/>
         <source>Error</source>
         <translation>Błąd</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="285"/>
+        <location filename="mainwindow.cpp" line="316"/>
         <source>Please select a USB device to write to</source>
         <translation>Wybierz urządzenie USB, którego chcesz użyć do zapisu</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="288"/>
-        <location filename="mainwindow.cpp" line="458"/>
+        <location filename="mainwindow.cpp" line="319"/>
+        <location filename="mainwindow.cpp" line="475"/>
         <source>clone</source>
         <translation>klonuj</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="327"/>
-        <source>About</source>
-        <translation>O</translation>
+        <location filename="mainwindow.cpp" line="355"/>
+        <source>About %1</source>
+        <translation>O %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="328"/>
+        <location filename="mainwindow.cpp" line="356"/>
         <source>Version: </source>
         <translation>Wersja:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="329"/>
+        <location filename="mainwindow.cpp" line="357"/>
         <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
         <translation>Program do tworzenia live-usb z pliku iso, z innego live-usb, z live-cd/dvd lub z uruchomionego systemu live.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="331"/>
+        <location filename="mainwindow.cpp" line="359"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Prawa autorskie © MX Linux</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="332"/>
-        <location filename="mainwindow.cpp" line="338"/>
-        <source>License</source>
-        <translation>Licencja</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="333"/>
-        <source>Cancel</source>
-        <translation>Anuluj</translation>
+        <location filename="mainwindow.cpp" line="360"/>
+        <source>%1 License</source>
+        <translation>%1 Licencja</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="368"/>
+        <source>%1 Help</source>
+        <translation>%1 Pomoc</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="379"/>
         <source>Select an ISO file to write to the USB drive</source>
         <translation>Wybierz plik ISO, który chcesz zapisać na dysku USB</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="374"/>
-        <location filename="mainwindow.cpp" line="442"/>
+        <location filename="mainwindow.cpp" line="387"/>
+        <location filename="mainwindow.cpp" line="458"/>
         <source>Select Source Directory</source>
         <translation>Wybierz katalog źródłowy</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="379"/>
+        <location filename="mainwindow.cpp" line="392"/>
         <source>Could not find %1/antiX/linuxfs file</source>
         <translation>Nie można znaleźć pliku %1/antiX/linuxfs</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="395"/>
+        <location filename="mainwindow.cpp" line="413"/>
         <source>Hide advanced options</source>
         <translation>Ukryj opcje zaawansowane</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="441"/>
-        <location filename="mainwindow.cpp" line="456"/>
+        <location filename="mainwindow.cpp" line="457"/>
+        <location filename="mainwindow.cpp" line="473"/>
         <source>Select Source</source>
         <translation>Wybierz źródło</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="445"/>
-        <location filename="mainwindow.cpp" line="462"/>
+        <location filename="mainwindow.cpp" line="461"/>
+        <location filename="mainwindow.cpp" line="479"/>
         <source>Select ISO file</source>
         <translation>Wybierz plik ISO</translation>
     </message>
@@ -340,7 +383,28 @@ Poczekaj, aż proces się zakończy.</translation>
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="main.cpp" line="52"/>
+        <location filename="about.cpp" line="32"/>
+        <source>License</source>
+        <translation>Licencja</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="33"/>
+        <location filename="about.cpp" line="43"/>
+        <source>Changelog</source>
+        <translation>Dziennik zmian</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="34"/>
+        <source>Cancel</source>
+        <translation>Anuluj</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="51"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Zamknij</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="75"/>
         <source>You must run this program as root.</source>
         <translation>Musisz uruchomić ten program jako administrator. </translation>
     </message>
